[dpdk-dev] [PATCH] RTE_PIPELINE_ACTION_PORT_META fix for non-default entries

2015-02-21 Thread Ildar Mustafin
---
 lib/librte_pipeline/rte_pipeline.c | 5 +
 1 file changed, 5 insertions(+)

diff --git a/lib/librte_pipeline/rte_pipeline.c 
b/lib/librte_pipeline/rte_pipeline.c
index ac7e887..36d92c9 100644
--- a/lib/librte_pipeline/rte_pipeline.c
+++ b/lib/librte_pipeline/rte_pipeline.c
@@ -999,6 +999,7 @@ rte_pipeline_compute_masks(struct rte_pipeline *p, uint64_t 
pkts_mask)
 {
p->action_mask1[RTE_PIPELINE_ACTION_DROP] = 0;
p->action_mask1[RTE_PIPELINE_ACTION_PORT] = 0;
+   p->action_mask1[RTE_PIPELINE_ACTION_PORT_META] = 0;
p->action_mask1[RTE_PIPELINE_ACTION_TABLE] = 0;

if ((pkts_mask & (pkts_mask + 1)) == 0) {
@@ -1224,6 +1225,7 @@ rte_pipeline_run(struct rte_pipeline *p)
pkts_mask = RTE_LEN2MASK(n_pkts, uint64_t);
p->action_mask0[RTE_PIPELINE_ACTION_DROP] = 0;
p->action_mask0[RTE_PIPELINE_ACTION_PORT] = 0;
+   p->action_mask0[RTE_PIPELINE_ACTION_PORT_META] = 0;
p->action_mask0[RTE_PIPELINE_ACTION_TABLE] = 0;

/* Input port user actions */
@@ -1300,6 +1302,9 @@ rte_pipeline_run(struct rte_pipeline *p)
p->action_mask0[RTE_PIPELINE_ACTION_PORT] |=
p->action_mask1[
RTE_PIPELINE_ACTION_PORT];
+   p->action_mask0[RTE_PIPELINE_ACTION_PORT_META] 
|=
+   p->action_mask1[
+   RTE_PIPELINE_ACTION_PORT_META];
p->action_mask0[RTE_PIPELINE_ACTION_TABLE] |=
p->action_mask1[
RTE_PIPELINE_ACTION_TABLE];
-- 
1.9.1



[dpdk-dev] [PATCH v3 0/5] Integrate flex filter in igb driver to new API

2015-02-21 Thread Pablo de Lara
The patch set uses new filter_ctrl API to replace old flex filter APIs.
It uses new functions and structure to replace old ones in igb driver, new 
commands to replace old ones in testpmd, and removes the old APIs.

v3 changes:
 - fix testpmd documentation

v2 changes:
 - split one patch to patch series
 - change the command's format in testpmd.
 - add doc changes in testpmd_funcs.rst
 - correct the errors reported by checkpatch.pl

Jingjing Wu (5):
  ethdev: define flex filter type and its structure
  e1000: new functions replace old ones for flex filter
  testpmd: new commands for flex filter
  ethdev: remove old APIs and structures of flex filter
  doc: commands changed in testpmd_funcs for flex filter

 app/test-pmd/cmdline.c  |  239 
 app/test-pmd/config.c   |   33 ---
 app/test-pmd/testpmd.h  |1 -
 doc/guides/testpmd_app_ug/testpmd_funcs.rst |   64 ++
 lib/librte_ether/rte_eth_ctrl.h |   20 ++
 lib/librte_ether/rte_ethdev.c   |   51 
 lib/librte_ether/rte_ethdev.h   |   89 ---
 lib/librte_pmd_e1000/e1000_ethdev.h |   27 ++-
 lib/librte_pmd_e1000/igb_ethdev.c   |  332 +--
 9 files changed, 356 insertions(+), 500 deletions(-)

-- 
1.7.4.1



[dpdk-dev] [PATCH v3 1/5] ethdev: define flex filter type and its structure

2015-02-21 Thread Pablo de Lara
From: Jingjing Wu 

This patch defines flex filter type RTE_ETH_FILTER_FLEXIBLE and its structure 
rte_eth_flex_filter.

Signed-off-by: Jingjing Wu 
---
 lib/librte_ether/rte_eth_ctrl.h |   20 
 1 files changed, 20 insertions(+), 0 deletions(-)

diff --git a/lib/librte_ether/rte_eth_ctrl.h b/lib/librte_ether/rte_eth_ctrl.h
index 0ce241e..beacfa3 100644
--- a/lib/librte_ether/rte_eth_ctrl.h
+++ b/lib/librte_ether/rte_eth_ctrl.h
@@ -53,6 +53,7 @@ enum rte_filter_type {
RTE_ETH_FILTER_NONE = 0,
RTE_ETH_FILTER_MACVLAN,
RTE_ETH_FILTER_ETHERTYPE,
+   RTE_ETH_FILTER_FLEXIBLE,
RTE_ETH_FILTER_TUNNEL,
RTE_ETH_FILTER_FDIR,
RTE_ETH_FILTER_HASH,
@@ -116,6 +117,25 @@ struct rte_eth_ethertype_filter {
uint16_t queue;   /**< Queue assigned to when match*/
 };

+#define RTE_FLEX_FILTER_MAXLEN 128 /**< bytes to use in flex filter. */
+#define RTE_FLEX_FILTER_MASK_SIZE  \
+   (RTE_ALIGN(RTE_FLEX_FILTER_MAXLEN, CHAR_BIT) / CHAR_BIT)
+   /**< mask bytes in flex filter. */
+
+/**
+ *  A structure used to define the flex filter entry
+ *  to support RTE_ETH_FILTER_FLEXIBLE with RTE_ETH_FILTER_ADD,
+ *  RTE_ETH_FILTER_DELETE and RTE_ETH_FILTER_GET operations.
+ */
+struct rte_eth_flex_filter {
+   uint16_t len;
+   uint8_t bytes[RTE_FLEX_FILTER_MAXLEN];  /**< flex bytes in big endian.*/
+   uint8_t mask[RTE_FLEX_FILTER_MASK_SIZE];/**< if mask bit is 1b, do
+   not compare corresponding byte. */
+   uint8_t priority;
+   uint16_t queue;   /**< Queue assigned to when match. */
+};
+
 /**
  * Tunneled type.
  */
-- 
1.7.4.1



[dpdk-dev] [PATCH v3 5/5] doc: commands changed in testpmd_funcs for flex filter

2015-02-21 Thread Pablo de Lara
From: Jingjing Wu 

document of new command:
  - flex_filter (port_id) (add|del) len (len_value) bytes (bytes_value)
mask (mask_value) priority (prio_value) queue (queue_id)

Signed-off-by: Jingjing Wu 
Signed-off-by: Pablo de Lara 
---
 doc/guides/testpmd_app_ug/testpmd_funcs.rst |   64 ++-
 1 files changed, 14 insertions(+), 50 deletions(-)

diff --git a/doc/guides/testpmd_app_ug/testpmd_funcs.rst 
b/doc/guides/testpmd_app_ug/testpmd_funcs.rst
index 218835a..a0cdad7 100644
--- a/doc/guides/testpmd_app_ug/testpmd_funcs.rst
+++ b/doc/guides/testpmd_app_ug/testpmd_funcs.rst
@@ -1595,71 +1595,35 @@ Example:

 syn filter: on, priority: high, queue: 3

-add_flex_filter
-~~~
+flex_filter
+~~~

-Add a Flex filter,
-which recognizes any arbitrary pattern within the first 128 bytes of the packet
+With flex filter, packets can be recognized by any arbitrary pattern within 
the first 128 bytes of the packet
 and routes packets into one of the receive queues.

-add_flex_filter (port_id) len (len_value) bytes (bytes_string) mask 
(mask_value)
-priority (prio_value) queue (queue_id) index (idx)
+flex_filter (port_id) (add|del) len (len_value) bytes (bytes_value)
+mask (mask_value) priority (prio_value) queue (queue_id)

 The available information parameters are:

-*   port_id: the port which the Flex filter assigned on.
+*   port_id: the port which the Flex filter is assigned on.

-*   len_value: filter length in byte, no greater than 128.
+*   len_value: filter length in bytes, no greater than 128.

-*   bytes_string: a sting in format of octal, means the value the flex filter 
need to match.
+*   bytes_value: a string in hexadecimal, means the value the flex filter 
needs to match.

-*   mask_value: a sting in format of octal, bit 1 means corresponding byte in 
DWORD participates in the match.
+*   mask_value: a string in hexadecimal, bit 1 means corresponding byte 
participates in the match.

 *   prio_value: the priority of this filter.

-*   queue_id: The receive queue associated with this Flex filter.
-
-*   index: the index of this Flex filter
+*   queue_id: the receive queue associated with this Flex filter.

 Example:

 .. code-block:: console

-   testpmd> add_flex_filter 0 len 16 bytes 0x0806 
mask 000C priority 3 queue 3 index 0
-
-Assign a packet whose 13th and 14th bytes are 0x0806 to queue 3.
-
-remove_flex_filter
-~~
-
-Remove a Flex filter
-
-remove_flex_filter (port_id) index (idx)
-
-get_flex_filter
-~~~
-
-Get and display a Flex filter
-
-get_flex_filter (port_id) index (idx)
+   testpmd> flex_filter 0 add len 16 bytes 0x0806
+mask 000C priority 3 queue 3

-Example:
-
-.. code-block:: console
-
-testpmd> get_flex_filter 0 index 0
-
-filter[0]:
-
-length: 16
-
-dword[]: 0x   0806   

-        

-        

-      
-
-mask[]:
-0b11
-00
-
-priority: 3   queue: 3
+   testpmd> flex_filter 0 del len 16 bytes 0x0806
+mask 000C priority 3 queue 3
-- 
1.7.4.1



[dpdk-dev] [PATCH v3 2/5] e1000: new functions replace old ones for flex filter

2015-02-21 Thread Pablo de Lara
From: Jingjing Wu 

This patch defines new functions dealing with flex filter.
It removes old functions of flex filter in igb driver.
Syn filter is dealt with through entrance eth_igb_filter_ctrl.

Signed-off-by: Jingjing Wu 
---
 lib/librte_pmd_e1000/e1000_ethdev.h |   27 +++-
 lib/librte_pmd_e1000/igb_ethdev.c   |  332 +-
 2 files changed, 231 insertions(+), 128 deletions(-)

diff --git a/lib/librte_pmd_e1000/e1000_ethdev.h 
b/lib/librte_pmd_e1000/e1000_ethdev.h
index d155e77..b91fcad 100644
--- a/lib/librte_pmd_e1000/e1000_ethdev.h
+++ b/lib/librte_pmd_e1000/e1000_ethdev.h
@@ -78,11 +78,16 @@
 #define E1000_MAX_TTQF_FILTERS 8
 #define E1000_2TUPLE_MAX_PRI   7

-#define E1000_MAX_FLEXIBLE_FILTERS   8
+#define E1000_MAX_FLEX_FILTERS   8
 #define E1000_MAX_FHFT   4
 #define E1000_MAX_FHFT_EXT   4
+#define E1000_FHFT_SIZE_IN_DWD   64
 #define E1000_MAX_FLEX_FILTER_PRI7
 #define E1000_MAX_FLEX_FILTER_LEN128
+#define E1000_MAX_FLEX_FILTER_DWDS \
+   (E1000_MAX_FLEX_FILTER_LEN / sizeof(uint32_t))
+#define E1000_FLEX_FILTERS_MASK_SIZE \
+   (E1000_MAX_FLEX_FILTER_DWDS / 4)
 #define E1000_FHFT_QUEUEING_LEN  0x007F
 #define E1000_FHFT_QUEUEING_QUEUE0x0700
 #define E1000_FHFT_QUEUEING_PRIO 0x0007
@@ -131,6 +136,24 @@ struct e1000_vf_info {
uint16_t tx_rate;
 };

+TAILQ_HEAD(e1000_flex_filter_list, e1000_flex_filter);
+
+struct e1000_flex_filter_info {
+   uint16_t len;
+   uint32_t dwords[E1000_MAX_FLEX_FILTER_DWDS]; /* flex bytes in dword. */
+   /* if mask bit is 1b, do not compare corresponding byte in dwords. */
+   uint8_t mask[E1000_FLEX_FILTERS_MASK_SIZE];
+   uint8_t priority;
+};
+
+/* Flex filter structure */
+struct e1000_flex_filter {
+   TAILQ_ENTRY(e1000_flex_filter) entries;
+   uint16_t index; /* index of flex filter */
+   struct e1000_flex_filter_info filter_info;
+   uint16_t queue; /* rx queue assigned to */
+};
+
 /*
  * Structure to store filters' info.
  */
@@ -138,6 +161,8 @@ struct e1000_filter_info {
uint8_t ethertype_mask; /* Bit mask for every used ethertype filter */
/* store used ethertype filters*/
uint16_t ethertype_filters[E1000_MAX_ETQF_FILTERS];
+   uint8_t flex_mask;  /* Bit mask for every used flex filter */
+   struct e1000_flex_filter_list flex_list;
 };

 /*
diff --git a/lib/librte_pmd_e1000/igb_ethdev.c 
b/lib/librte_pmd_e1000/igb_ethdev.c
index 2a268b8..6e9240e 100644
--- a/lib/librte_pmd_e1000/igb_ethdev.c
+++ b/lib/librte_pmd_e1000/igb_ethdev.c
@@ -162,14 +162,14 @@ static int eth_igb_remove_2tuple_filter(struct 
rte_eth_dev *dev,
 static int eth_igb_get_2tuple_filter(struct rte_eth_dev *dev,
uint16_t index,
struct rte_2tuple_filter *filter, uint16_t *rx_queue);
-static int eth_igb_add_flex_filter(struct rte_eth_dev *dev,
-   uint16_t index,
-   struct rte_flex_filter *filter, uint16_t rx_queue);
-static int eth_igb_remove_flex_filter(struct rte_eth_dev *dev,
-   uint16_t index);
+static int eth_igb_add_del_flex_filter(struct rte_eth_dev *dev,
+   struct rte_eth_flex_filter *filter,
+   bool add);
 static int eth_igb_get_flex_filter(struct rte_eth_dev *dev,
-   uint16_t index,
-   struct rte_flex_filter *filter, uint16_t *rx_queue);
+   struct rte_eth_flex_filter *filter);
+static int eth_igb_flex_filter_handle(struct rte_eth_dev *dev,
+   enum rte_filter_op filter_op,
+   void *arg);
 static int eth_igb_add_5tuple_filter(struct rte_eth_dev *dev,
uint16_t index,
struct rte_5tuple_filter *filter, uint16_t rx_queue);
@@ -271,9 +271,6 @@ static struct eth_dev_ops eth_igb_ops = {
.add_2tuple_filter   = eth_igb_add_2tuple_filter,
.remove_2tuple_filter= eth_igb_remove_2tuple_filter,
.get_2tuple_filter   = eth_igb_get_2tuple_filter,
-   .add_flex_filter = eth_igb_add_flex_filter,
-   .remove_flex_filter  = eth_igb_remove_flex_filter,
-   .get_flex_filter = eth_igb_get_flex_filter,
.add_5tuple_filter   = eth_igb_add_5tuple_filter,
.remove_5tuple_filter= eth_igb_remove_5tuple_filter,
.get_5tuple_filter   = eth_igb_get_5tuple_filter,
@@ -470,6 +467,8 @@ eth_igb_dev_init(__attribute__((unused)) struct eth_driver 
*eth_drv,
E1000_DEV_PRIVATE_TO_HW(eth_dev->data->dev_private);
struct e1000_vfta * shadow_vfta =
E1000_DEV_PRIVATE_TO_VFTA(eth_dev->data->dev_private);
+   struct e1000_filter_info *filter_info =
+   E1000_DEV_PRIVATE_TO_FILTER_INFO(eth_dev->data->dev_private);
uint32_t ctrl_ext

[dpdk-dev] [PATCH v3 4/5] ethdev: remove old APIs and structures of flex filter

2015-02-21 Thread Pablo de Lara
From: Jingjing Wu 

Structure rte_flex_filter is removed.
Following APIs are removed:
  - rte_eth_dev_add_flex_filter
  - rte_eth_dev_remove_flex_filter
  - rte_eth_dev_get_flex_filter

Signed-off-by: Jingjing Wu 
---
 lib/librte_ether/rte_ethdev.c |   51 ---
 lib/librte_ether/rte_ethdev.h |   89 -
 2 files changed, 0 insertions(+), 140 deletions(-)

diff --git a/lib/librte_ether/rte_ethdev.c b/lib/librte_ether/rte_ethdev.c
index 17be2f3..ccff0ef 100644
--- a/lib/librte_ether/rte_ethdev.c
+++ b/lib/librte_ether/rte_ethdev.c
@@ -3177,57 +3177,6 @@ rte_eth_dev_get_5tuple_filter(uint8_t port_id, uint16_t 
index,
 }

 int
-rte_eth_dev_add_flex_filter(uint8_t port_id, uint16_t index,
-   struct rte_flex_filter *filter, uint16_t rx_queue)
-{
-   struct rte_eth_dev *dev;
-
-   if (port_id >= nb_ports) {
-   PMD_DEBUG_TRACE("Invalid port_id=%d\n", port_id);
-   return -ENODEV;
-   }
-
-   dev = &rte_eth_devices[port_id];
-   FUNC_PTR_OR_ERR_RET(*dev->dev_ops->add_flex_filter, -ENOTSUP);
-   return (*dev->dev_ops->add_flex_filter)(dev, index, filter, rx_queue);
-}
-
-int
-rte_eth_dev_remove_flex_filter(uint8_t port_id, uint16_t index)
-{
-   struct rte_eth_dev *dev;
-
-   if (port_id >= nb_ports) {
-   PMD_DEBUG_TRACE("Invalid port_id=%d\n", port_id);
-   return -ENODEV;
-   }
-
-   dev = &rte_eth_devices[port_id];
-   FUNC_PTR_OR_ERR_RET(*dev->dev_ops->remove_flex_filter, -ENOTSUP);
-   return (*dev->dev_ops->remove_flex_filter)(dev, index);
-}
-
-int
-rte_eth_dev_get_flex_filter(uint8_t port_id, uint16_t index,
-   struct rte_flex_filter *filter, uint16_t *rx_queue)
-{
-   struct rte_eth_dev *dev;
-
-   if (filter == NULL || rx_queue == NULL)
-   return -EINVAL;
-
-   if (port_id >= nb_ports) {
-   PMD_DEBUG_TRACE("Invalid port_id=%d\n", port_id);
-   return -ENODEV;
-   }
-
-   dev = &rte_eth_devices[port_id];
-   FUNC_PTR_OR_ERR_RET(*dev->dev_ops->get_flex_filter, -ENOTSUP);
-   return (*dev->dev_ops->get_flex_filter)(dev, index, filter,
-   rx_queue);
-}
-
-int
 rte_eth_dev_filter_supported(uint8_t port_id, enum rte_filter_type filter_type)
 {
struct rte_eth_dev *dev;
diff --git a/lib/librte_ether/rte_ethdev.h b/lib/librte_ether/rte_ethdev.h
index fd8451a..82f2eb1 100644
--- a/lib/librte_ether/rte_ethdev.h
+++ b/lib/librte_ether/rte_ethdev.h
@@ -996,17 +996,6 @@ struct rte_2tuple_filter {
 };

 /**
- *  A structure used to define a flex filter.
- */
-struct rte_flex_filter {
-   uint16_t len;
-   uint32_t dwords[32];  /**< flex bytes in big endian. */
-   uint8_t mask[16]; /**< if mask bit is 1b, do not compare
-  corresponding byte in dwords. */
-   uint8_t priority;
-};
-
-/**
  *  A structure used to define a 5tuple filter.
  */
 struct rte_5tuple_filter {
@@ -1399,20 +1388,6 @@ typedef int (*eth_get_5tuple_filter_t)(struct 
rte_eth_dev *dev,
uint16_t *rx_queue);
 /**< @internal Get a 5tuple filter rule on an Ethernet device */

-typedef int (*eth_add_flex_filter_t)(struct rte_eth_dev *dev,
-   uint16_t index, struct rte_flex_filter *filter,
-   uint16_t rx_queue);
-/**< @internal Setup a new flex filter rule on an Ethernet device */
-
-typedef int (*eth_remove_flex_filter_t)(struct rte_eth_dev *dev,
-   uint16_t index);
-/**< @internal Remove a flex filter rule on an Ethernet device */
-
-typedef int (*eth_get_flex_filter_t)(struct rte_eth_dev *dev,
-   uint16_t index, struct rte_flex_filter *filter,
-   uint16_t *rx_queue);
-/**< @internal Get a flex filter rule on an Ethernet device */
-
 typedef int (*eth_filter_ctrl_t)(struct rte_eth_dev *dev,
 enum rte_filter_type filter_type,
 enum rte_filter_op filter_op,
@@ -1524,9 +1499,6 @@ struct eth_dev_ops {
eth_add_5tuple_filter_tadd_5tuple_filter;/**< add 5tuple 
filter. */
eth_remove_5tuple_filter_t remove_5tuple_filter; /**< remove 5tuple 
filter. */
eth_get_5tuple_filter_tget_5tuple_filter;/**< get 5tuple 
filter. */
-   eth_add_flex_filter_t  add_flex_filter;  /**< add flex 
filter. */
-   eth_remove_flex_filter_t   remove_flex_filter;   /**< remove flex 
filter. */
-   eth_get_flex_filter_t  get_flex_filter;  /**< get flex 
filter. */
eth_filter_ctrl_t  filter_ctrl;  /**< common filter 
control*/
 };

@@ -3579,67 +3551,6 @@ int rte_eth_dev_get_5tuple_filter(uint8_t port_id, 
uint16_t index,
struct rte_5tuple_filter *filter, uint16_t *rx_queue);

 /**
- * Add a new flex f

[dpdk-dev] [PATCH v3 3/5] testpmd: new commands for flex filter

2015-02-21 Thread Pablo de Lara
From: Jingjing Wu 

Following commands of flex filter are removed:
  - add_flex_filter (port_id) len (len_value) bytes (bytes_string) mask 
(mask_value)
priority (prio_value) queue (queue_id)
  - remove_flex_filter (port_id) index (idx)
  - get_flex_filter (port_id) index (idx)
New command is added for flex filter by using filter_ctrl API and new flex 
filter structure:
  - flex_filter (port_id) (add|del) len (len_value) bytes (bytes_value) mask 
(mask_value)
priority (prio_value) queue (queue_id)

Signed-off-by: Jingjing Wu 
---
 app/test-pmd/cmdline.c |  239 ++--
 app/test-pmd/config.c  |   33 ---
 app/test-pmd/testpmd.h |1 -
 3 files changed, 91 insertions(+), 182 deletions(-)

-- 
2.1.0



[dpdk-dev] [PATCH v2 1/4] scripts: add auto-config-h.sh

2015-02-21 Thread Adrien Mazarguil
This script looks for types, macros and functions in header files using
compilation options found in the environment (CC, CFLAGS, CPPFLAGS) to
define feature macros in a generated header.

Useful in combination with external headers that do not provide such macros.

Signed-off-by: Adrien Mazarguil 
---
 scripts/auto-config-h.sh | 137 +++
 1 file changed, 137 insertions(+)
 create mode 100755 scripts/auto-config-h.sh

diff --git a/scripts/auto-config-h.sh b/scripts/auto-config-h.sh
new file mode 100755
index 000..d897e80
--- /dev/null
+++ b/scripts/auto-config-h.sh
@@ -0,0 +1,137 @@
+#!/bin/sh
+#
+#   BSD LICENSE
+#
+#   Copyright(c) 2014-2015 6WIND S.A.
+#   All rights reserved.
+#
+#   Redistribution and use in source and binary forms, with or without
+#   modification, are permitted provided that the following conditions
+#   are met:
+#
+# * Redistributions of source code must retain the above copyright
+#   notice, this list of conditions and the following disclaimer.
+# * Redistributions in binary form must reproduce the above copyright
+#   notice, this list of conditions and the following disclaimer in
+#   the documentation and/or other materials provided with the
+#   distribution.
+# * Neither the name of 6WIND S.A. nor the names of its
+#   contributors may be used to endorse or promote products derived
+#   from this software without specific prior written permission.
+#
+#   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+#   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+#   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+#   A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+#   OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+#   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+#   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+#   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+#   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+#   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+#   OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+#
+# Crude script to detect whether particular types, macros and functions are
+# defined by trying to compile a file with a given header. Can be used to
+# perform cross-platform checks since the resulting object file is not
+# executed.
+#
+# Set VERBOSE=1 in the environment to display compiler output and errors.
+#
+# CC, CPPFLAGS, CFLAGS, EXTRA_CPPFLAGS and EXTRA_CFLAGS are taken from the
+# environment.
+#
+# AUTO_CONFIG_CFLAGS may append additional CFLAGS without modifying the
+# above variables.
+
+file=${1:?output file name required (config.h)}
+macro=${2:?output macro name required (HAVE_*)}
+include=${3:?include name required (foo.h)}
+type=${4:?object type required (define, enum, type, field, func)}
+name=${5:?define/type/function name required}
+
+: ${CC:=cc}
+
+temp=/tmp/${0##*/}.$$.c
+
+case $type in
+define)
+   code="\
+#ifndef $name
+#error $name not defined
+#endif
+"
+   ;;
+enum)
+   code="\
+long test = $name;
+"
+   ;;
+type)
+   code="\
+$name test;
+"
+   ;;
+field)
+   code="\
+void test(void)
+{
+   ${name%%.*} test_;
+
+   (void)test_.${name#*.};
+}
+"
+   ;;
+func)
+   code="\
+void (*test)() = (void (*)())$name;
+"
+   ;;
+*)
+   unset error
+   : ${error:?unknown object type \"$type\"}
+   exit
+esac
+
+if [ "${VERBOSE}" = 1 ]
+then
+   err=2
+   out=1
+   eol='
+'
+else
+   exec 3> /dev/null ||
+   exit
+   err=3
+   out=3
+   eol=' '
+fi &&
+printf 'Looking for %s %s in %s.%s' \
+   "${name}" "${type}" "${include}" "${eol}" &&
+printf "\
+#include <%s>
+
+%s
+" "$include" "$code" > "${temp}" &&
+if ${CC} ${CPPFLAGS} ${EXTRA_CPPFLAGS} ${CFLAGS} ${EXTRA_CFLAGS} \
+   ${AUTO_CONFIG_CFLAGS} \
+   -c -o /dev/null "${temp}" 1>&${out} 2>&${err}
+then
+   rm -f "${temp}"
+   printf "\
+#ifndef %s
+#define %s 1
+#endif /* %s */
+
+" "${macro}" "${macro}" "${macro}" >> "${file}" &&
+   printf 'Defining %s.\n' "${macro}"
+else
+   rm -f "${temp}"
+   printf "\
+/* %s is not defined. */
+
+" "${macro}" >> "${file}" &&
+   printf 'Not defining %s.\n' "${macro}"
+fi
+
+exit
-- 
2.1.0



[dpdk-dev] [PATCH v2 2/4] mlx4: new poll mode driver

2015-02-21 Thread Adrien Mazarguil
This PMD manages all variants of Mellanox ConnectX-3 (EN 40, EN 10, Pro EN
40) as well as their virtual functions in SR-IOV context through IB Verbs
(libibverbs) and the dedicated user-space driver (libmlx4).

It is disabled by default due to dependencies on these libraries and only
supports Linux userland at the moment partly because /sys (sysfs) support is
required.

Signed-off-by: Adrien Mazarguil 
Signed-off-by: Olga Shern 
---
 config/common_bsdapp |   11 +
 config/common_linuxapp   |   11 +
 lib/Makefile |1 +
 lib/librte_pmd_mlx4/Makefile |  119 ++
 lib/librte_pmd_mlx4/mlx4.c   | 4739 ++
 lib/librte_pmd_mlx4/mlx4.h   |  166 ++
 mk/rte.app.mk|8 +
 7 files changed, 5055 insertions(+)
 create mode 100755 lib/librte_pmd_mlx4/Makefile
 create mode 100755 lib/librte_pmd_mlx4/mlx4.c
 create mode 100644 lib/librte_pmd_mlx4/mlx4.h

diff --git a/config/common_bsdapp b/config/common_bsdapp
index f11ff39..3ba2c79 100644
--- a/config/common_bsdapp
+++ b/config/common_bsdapp
@@ -193,6 +193,17 @@ CONFIG_RTE_LIBRTE_FM10K_DEBUG_DRIVER=n
 CONFIG_RTE_LIBRTE_FM10K_RX_OLFLAGS_ENABLE=y

 #
+# Compile burst-oriented Mellanox ConnectX-3 (MLX4) PMD
+#
+CONFIG_RTE_LIBRTE_MLX4_PMD=n
+CONFIG_RTE_LIBRTE_MLX4_DEBUG=n
+CONFIG_RTE_LIBRTE_MLX4_SGE_WR_N=4
+CONFIG_RTE_LIBRTE_MLX4_MAX_INLINE=0
+CONFIG_RTE_LIBRTE_MLX4_TX_MP_CACHE=8
+CONFIG_RTE_LIBRTE_MLX4_SOFT_COUNTERS=1
+CONFIG_RTE_LIBRTE_MLX4_COMPAT_VMWARE=1
+
+#
 # Compile burst-oriented Cisco ENIC PMD driver
 #
 CONFIG_RTE_LIBRTE_ENIC_PMD=y
diff --git a/config/common_linuxapp b/config/common_linuxapp
index f921d8c..e79559d 100644
--- a/config/common_linuxapp
+++ b/config/common_linuxapp
@@ -191,6 +191,17 @@ CONFIG_RTE_LIBRTE_FM10K_DEBUG_DRIVER=n
 CONFIG_RTE_LIBRTE_FM10K_RX_OLFLAGS_ENABLE=y

 #
+# Compile burst-oriented Mellanox ConnectX-3 (MLX4) PMD
+#
+CONFIG_RTE_LIBRTE_MLX4_PMD=n
+CONFIG_RTE_LIBRTE_MLX4_DEBUG=n
+CONFIG_RTE_LIBRTE_MLX4_SGE_WR_N=4
+CONFIG_RTE_LIBRTE_MLX4_MAX_INLINE=0
+CONFIG_RTE_LIBRTE_MLX4_TX_MP_CACHE=8
+CONFIG_RTE_LIBRTE_MLX4_SOFT_COUNTERS=1
+CONFIG_RTE_LIBRTE_MLX4_COMPAT_VMWARE=1
+
+#
 # Compile burst-oriented Cisco ENIC PMD driver
 #
 CONFIG_RTE_LIBRTE_ENIC_PMD=y
diff --git a/lib/Makefile b/lib/Makefile
index 6575a4e..07daf6a 100644
--- a/lib/Makefile
+++ b/lib/Makefile
@@ -45,6 +45,7 @@ DIRS-$(CONFIG_RTE_LIBRTE_E1000_PMD) += librte_pmd_e1000
 DIRS-$(CONFIG_RTE_LIBRTE_IXGBE_PMD) += librte_pmd_ixgbe
 DIRS-$(CONFIG_RTE_LIBRTE_I40E_PMD) += librte_pmd_i40e
 DIRS-$(CONFIG_RTE_LIBRTE_FM10K_PMD) += librte_pmd_fm10k
+DIRS-$(CONFIG_RTE_LIBRTE_MLX4_PMD) += librte_pmd_mlx4
 DIRS-$(CONFIG_RTE_LIBRTE_ENIC_PMD) += librte_pmd_enic
 DIRS-$(CONFIG_RTE_LIBRTE_PMD_BOND) += librte_pmd_bond
 DIRS-$(CONFIG_RTE_LIBRTE_PMD_RING) += librte_pmd_ring
diff --git a/lib/librte_pmd_mlx4/Makefile b/lib/librte_pmd_mlx4/Makefile
new file mode 100755
index 000..9a6c891
--- /dev/null
+++ b/lib/librte_pmd_mlx4/Makefile
@@ -0,0 +1,119 @@
+#   BSD LICENSE
+#
+#   Copyright(c) 2012-2015 6WIND S.A.
+#   Copyright(c) 2012 Mellanox.
+#   All rights reserved.
+#
+#   Redistribution and use in source and binary forms, with or without
+#   modification, are permitted provided that the following conditions
+#   are met:
+#
+# * Redistributions of source code must retain the above copyright
+#   notice, this list of conditions and the following disclaimer.
+# * Redistributions in binary form must reproduce the above copyright
+#   notice, this list of conditions and the following disclaimer in
+#   the documentation and/or other materials provided with the
+#   distribution.
+# * Neither the name of 6WIND S.A. nor the names of its
+#   contributors may be used to endorse or promote products derived
+#   from this software without specific prior written permission.
+#
+#   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+#   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+#   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+#   A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+#   OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+#   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+#   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+#   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+#   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+#   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+#   OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+
+include $(RTE_SDK)/mk/rte.vars.mk
+
+# Library name.
+LIB = librte_pmd_mlx4.a
+
+# Sources.
+SRCS-$(CONFIG_RTE_LIBRTE_MLX4_PMD) += mlx4.c
+
+# Dependencies.
+DEPDIRS-$(CONFIG_RTE_LIBRTE_MLX4_PMD) += lib/librte_ether
+DEPDIRS-$(CONFIG_RTE_LIBRTE_MLX4_PMD) += lib/librte_mbuf
+DEPDIRS-$(CONFIG_RTE_LIBRTE_MLX4_PMD) += lib/l

[dpdk-dev] [PATCH v2 3/4] maintainers: claim responsibility for mlx4 PMD

2015-02-21 Thread Adrien Mazarguil
Signed-off-by: Adrien Mazarguil 
---
 MAINTAINERS | 4 
 1 file changed, 4 insertions(+)

diff --git a/MAINTAINERS b/MAINTAINERS
index 7ac6d59..b4328d6 100644
--- a/MAINTAINERS
+++ b/MAINTAINERS
@@ -217,6 +217,10 @@ Intel fm10k
 M: Jing Chen 
 F: lib/librte_pmd_fm10k/

+Mellanox mlx4
+M: Adrien Mazarguil 
+F: lib/librte_pmd_mlx4/
+
 RedHat virtio
 M: Changchun Ouyang 
 F: lib/librte_pmd_virtio/
-- 
2.1.0



[dpdk-dev] [PATCH v2 4/4] doc: add librte_pmd_mlx4 documentation

2015-02-21 Thread Adrien Mazarguil
This documentation covers implementation details, features and limitations,
configuration, prerequisites and provides a usage example.

Signed-off-by: Adrien Mazarguil 
---
 doc/guides/prog_guide/index.rst  |   1 +
 doc/guides/prog_guide/mlx4_poll_mode_drv.rst | 327 +++
 doc/guides/prog_guide/source_org.rst |   1 +
 3 files changed, 329 insertions(+)
 create mode 100644 doc/guides/prog_guide/mlx4_poll_mode_drv.rst

diff --git a/doc/guides/prog_guide/index.rst b/doc/guides/prog_guide/index.rst
index de69682..87f6b35 100644
--- a/doc/guides/prog_guide/index.rst
+++ b/doc/guides/prog_guide/index.rst
@@ -56,6 +56,7 @@ Programmer's Guide
 intel_dpdk_xen_based_packet_switch_sol
 libpcap_ring_based_poll_mode_drv
 link_bonding_poll_mode_drv_lib
+mlx4_poll_mode_drv
 timer_lib
 hash_lib
 lpm_lib
diff --git a/doc/guides/prog_guide/mlx4_poll_mode_drv.rst 
b/doc/guides/prog_guide/mlx4_poll_mode_drv.rst
new file mode 100644
index 000..e2c6b92
--- /dev/null
+++ b/doc/guides/prog_guide/mlx4_poll_mode_drv.rst
@@ -0,0 +1,327 @@
+..  BSD LICENSE
+Copyright(c) 2012-2015 6WIND S.A.
+All rights reserved.
+
+Redistribution and use in source and binary forms, with or without
+modification, are permitted provided that the following conditions
+are met:
+
+* Redistributions of source code must retain the above copyright
+notice, this list of conditions and the following disclaimer.
+* Redistributions in binary form must reproduce the above copyright
+notice, this list of conditions and the following disclaimer in
+the documentation and/or other materials provided with the
+distribution.
+* Neither the name of 6WIND S.A. nor the names of its
+contributors may be used to endorse or promote products derived
+from this software without specific prior written permission.
+
+THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+
+MLX4 poll mode driver library
+=
+
+The MLX4 poll mode driver library (**librte_pmd_mlx4**) implements support
+for **Mellanox ConnectX-3** 10/40 Gbps adapters (EN 40, EN 10, Pro EN 40) as
+well as their virtual functions (VF) in SR-IOV context.
+
+.. note::
+
+   Due to external dependencies, this driver is disabled by default. It must
+   be enabled manually by setting ``CONFIG_RTE_LIBRTE_MLX4_PMD=y`` and
+   recompiling DPDK.
+
+Implementation details
+--
+
+Most Mellanox ConnectX-3 devices provide two ports but expose a single PCI
+bus address, thus unlike most drivers, librte_pmd_mlx4 registers itself as a
+PCI driver that allocates one Ethernet device per detected port.
+
+For this reason, one cannot white/blacklist a single port without also
+white/blacklisting the others on the same device.
+
+Besides its dependency on libibverbs (that implies libmlx4 and associated
+kernel support), librte_pmd_mlx4 relies heavily on system calls for control
+operations such as querying/updating the MTU and flow control parameters.
+
+For security reasons and robustness, this driver only deals with virtual
+memory addresses. The way resources allocations are handled by the kernel
+combined with hardware specifications that allow it to handle virtual memory
+addresses directly ensure that DPDK applications cannot access random
+physical memory (or memory that does not belong to the current process).
+
+This capability allows the PMD to coexist with kernel network interfaces
+which remain functional, although they stop receiving unicast packets as
+long as they share the same MAC address.
+
+Compiling librte_pmd_mlx4 causes DPDK to be linked against libibverbs.
+
+Features and limitations
+
+
+- RSS, also known as RCA, is supported. In this mode the number of
+  configured RX queues must be a power of two.
+- VLAN filtering is supported.
+- Link state information is provided.
+- Promiscuous mode is supported.
+- All multicast mode is supported.
+- Multiple MAC addresses (unicast, multicast) can be configured.
+- Scattered packets are supported for TX and RX.
+
+..
+
+- RSS hash key cannot be modified.
+- Hardware counters are not implemented (they are software counters).
+- Checksu

[dpdk-dev] [PATCH] RTE_PIPELINE_ACTION_PORT_META fix for non-default entries

2015-02-21 Thread Ildar Mustafin
Signed-off-by: Ildar Mustafin 
---
 lib/librte_pipeline/rte_pipeline.c | 5 +
 1 file changed, 5 insertions(+)

diff --git a/lib/librte_pipeline/rte_pipeline.c 
b/lib/librte_pipeline/rte_pipeline.c
index ac7e887..36d92c9 100644
--- a/lib/librte_pipeline/rte_pipeline.c
+++ b/lib/librte_pipeline/rte_pipeline.c
@@ -999,6 +999,7 @@ rte_pipeline_compute_masks(struct rte_pipeline *p, uint64_t 
pkts_mask)
 {
p->action_mask1[RTE_PIPELINE_ACTION_DROP] = 0;
p->action_mask1[RTE_PIPELINE_ACTION_PORT] = 0;
+   p->action_mask1[RTE_PIPELINE_ACTION_PORT_META] = 0;
p->action_mask1[RTE_PIPELINE_ACTION_TABLE] = 0;

if ((pkts_mask & (pkts_mask + 1)) == 0) {
@@ -1224,6 +1225,7 @@ rte_pipeline_run(struct rte_pipeline *p)
pkts_mask = RTE_LEN2MASK(n_pkts, uint64_t);
p->action_mask0[RTE_PIPELINE_ACTION_DROP] = 0;
p->action_mask0[RTE_PIPELINE_ACTION_PORT] = 0;
+   p->action_mask0[RTE_PIPELINE_ACTION_PORT_META] = 0;
p->action_mask0[RTE_PIPELINE_ACTION_TABLE] = 0;

/* Input port user actions */
@@ -1300,6 +1302,9 @@ rte_pipeline_run(struct rte_pipeline *p)
p->action_mask0[RTE_PIPELINE_ACTION_PORT] |=
p->action_mask1[
RTE_PIPELINE_ACTION_PORT];
+   p->action_mask0[RTE_PIPELINE_ACTION_PORT_META] 
|=
+   p->action_mask1[
+   RTE_PIPELINE_ACTION_PORT_META];
p->action_mask0[RTE_PIPELINE_ACTION_TABLE] |=
p->action_mask1[
RTE_PIPELINE_ACTION_TABLE];
diff --git a/app/test-pmd/cmdline.c b/app/test-pmd/cmdline.c
index d37610a..ca2ff62 100644
--- a/app/test-pmd/cmdline.c
+++ b/app/test-pmd/cmdline.c
@@ -698,15 +698,10 @@ static void cmd_help_long_parsed(void *parsed_result,
"get_syn_filter (port_id) "
"get syn filter info.\n\n"

-   "add_flex_filter (port_id) len (len_value) bytes 
(bytes_string) mask (mask_value)"
-   " priority (prio_value) queue (queue_id) index (idx)\n"
-   "add a flex filter.\n\n"
-
-   "remove_flex_filter (port_id) index (idx)\n"
-   "remove a flex filter.\n\n"
-
-   "get_flex_filter (port_id) index (idx)\n"
-   "get info of a flex filter.\n\n"
+   "flex_filter (port_id) (add|del) len (len_value)"
+   " bytes (bytes_value) mask (mask_value)"
+   " priority (prio_value) queue (queue_id)\n"
+   "Add/Del a flex filter.\n\n"

"flow_director_filter (port_id) (add|del)"
" flow (ip4|ip4-frag|ip6|ip6-frag)"
@@ -7828,6 +7823,7 @@ cmdline_parse_inst_t cmd_get_5tuple_filter = {
 /* *** ADD/REMOVE A flex FILTER *** */
 struct cmd_flex_filter_result {
cmdline_fixed_string_t filter;
+   cmdline_fixed_string_t ops;
uint8_t port_id;
cmdline_fixed_string_t len;
uint8_t len_value;
@@ -7839,8 +7835,6 @@ struct cmd_flex_filter_result {
uint8_t priority_value;
cmdline_fixed_string_t queue;
uint16_t queue_id;
-   cmdline_fixed_string_t index;
-   uint16_t index_value;
 };

 static int xdigit2val(unsigned char c)
@@ -7861,113 +7855,106 @@ cmd_flex_filter_parsed(void *parsed_result,
  __attribute__((unused)) void *data)
 {
int ret = 0;
-   struct rte_flex_filter filter;
+   struct rte_eth_flex_filter filter;
struct cmd_flex_filter_result *res = parsed_result;
char *bytes_ptr, *mask_ptr;
-   uint16_t len, i, j;
+   uint16_t len, i, j = 0;
char c;
-   int val, mod = 0;
-   uint32_t dword = 0;
+   int val;
uint8_t byte = 0;
-   uint8_t hex = 0;

-   if (!strcmp(res->filter, "add_flex_filter")) {
-   if (res->len_value > 128) {
-   printf("the len exceed the max length 128\n");
-   return;
-   }
-   memset(&filter, 0, sizeof(struct rte_flex_filter));
-   filter.len = res->len_value;
-   filter.priority = res->priority_value;
-   bytes_ptr = res->bytes_value;
-   mask_ptr = res->mask_value;
-
-   j = 0;
-/* translate bytes string to uint_32 array. */
-   if (bytes_ptr[0] == '0' && ((bytes_ptr[1] == 'x') ||
-   (bytes_ptr[1] == 'X')))
-   bytes_ptr += 2;
-   len = strnlen(bytes_ptr, res->len_value * 2);
-   if (len == 0 || (len % 8 != 0)) {
-   printf("please check len and bytes input\n");
+   if (res->len_value > RTE_FLEX_FILTER_MAXLEN) {
+   printf("the len exceed the max length 128\n");
+   return;
+   }
+   memset(&filter, 0, sizeof(struct rte_eth_flex_filter));
+   filter.len = res->len_value;
+   filter.priority = res->priority_value;
+   filter.queue = res->queue_id;
+   bytes_ptr = res->bytes_value;
+   mask_ptr = res->mask_value;
+
+/* translate bytes string to array. */
+   if (bytes_ptr[0] == '0' && ((bytes_ptr[1] == 'x') ||
+   (bytes_ptr[1] == 'X')))
+   bytes_ptr += 2;
+   len = strnlen(bytes_ptr, res->len_value * 2);
+   if (len == 0 || (len % 8 != 0)) {
+   printf("please check len and bytes input\n");
+   return;
+   }
+   for (i = 0; i < len; i++) {
+   c = bytes_ptr[i];
+   if (isxdigit(c) == 0) {
+   /* invalid characters. */
+   printf("invalid input\n");
 

[dpdk-dev] [PATCH v4 4/5] eal: add per rx queue interrupt handling based on VFIO

2015-02-21 Thread Jun Xiao
On 02/19, Zhou Danny wrote:
> v4 changes:
> - Adjust position of new-added structure fields
> 
> v3 changes:
> - Fix review comments
> 
> v2 changes:
> - Fix compilation issue for a missed header file
> - Bug fix: free unreleased resources on the exception path before return
> - Consolidate coding style related review comments
> 
> This patch does below:
> - Create multiple VFIO eventfd for rx queues.
> - Handle per rx queue interrupt.
> - Eliminate unnecessary suspended DPDK polling thread wakeup mechanism
> for rx interrupt by allowing polling thread epoll_wait rx queue
> interrupt notification.
> 
> Signed-off-by: Danny Zhou 
> Tested-by: Yong Liu 
> ---
>  lib/librte_eal/common/include/rte_eal.h|  12 ++
>  lib/librte_eal/linuxapp/eal/Makefile   |   1 +
>  lib/librte_eal/linuxapp/eal/eal_interrupts.c   | 190 
> -
>  lib/librte_eal/linuxapp/eal/eal_pci_vfio.c |  12 +-
>  .../linuxapp/eal/include/exec-env/rte_interrupts.h |   4 +

Hi Danny,

Could you rebase the patch to your commit 4a499c64959, otherwise
rte_interrupts.h cannot be applied.

Thanks,
Jun


[dpdk-dev] [PATCH v10 13/14] eal/pci: Add rte_eal_dev_attach/detach() functions

2015-02-21 Thread Tetsuya Mukawa
On 2015/02/21 0:20, Maxime Leroy wrote:
> Hi Tetsuya,
>
> Thanks for your comment.
>
> On Fri, Feb 20, 2015 at 11:32 AM, Tetsuya Mukawa  wrote:
>> On 2015/02/20 19:14, Maxime Leroy wrote:
>>> Hi Tetsuya,
> [...]
>> Hi Maxime,
>>
>> I appreciate for your comment.
>>
>> When rte_eal_init() is called, if we have "--vdev" options, these will
>> be stored in vdevargs as you describe above.
>> I agree this is the current behavior of DPDK.
>>
>> When we call hotplug functions, I guess doing same thing will be more
>> consistent design.
> The rte_eal_devargs_add is here to store a white list parameters for
> later creating the devices.
> It means that the devargs_list is only needed at the init to store the
> devargs parsed .
> I think we should not use the devargs_list after eal initialization.
>
> Why you want to add devargs in the devargs_list, if there are no needs
> to store this information ?

In eal initialization code, virtual device names stored in devargs are
checked not to register a same device name twice.
And each init function of PMD just trust a device name received by eal.
So there is no code in PMD to check whether device name is unique.

For example, according to your suggestion, how to prevent below case?
$ ./testpmd -c f -n 1 -- -i
testpmd> port attach eth_pcap0,iface=eth0
testpmd> port attach eth_pcap0,iface=eth1

Also, type below, after doing above.
testpmd> port detach 0

Probably port 0 will be "eth_pcap0,iface=eth0".
But uninit code of PMD only receives a device name like 'eth_pcap0'.
(We have 2 'eth_pcap0' devices in PMD.)

To prevent above case, probably we have 2 options at least.
One is changing init code of all virtual PMDs not to register same
device name.
The other is to use devargs_list in EAL, and call init code of PMD with
a unique device name.

But first case, eal initialization code can calls init of PMD with
unique name, but hotplug cannot.
It's not so consistent behavior.
Also, we need to have almost same code that assure unique name in each PMD.

> At the end, it adds extra codes for nothing.
>
>> For example, we can do like below.
>> 1. $ ./testpmd --vdev 'eth_pcap' -- -i
>> 2. testpmd>port detach
> It's exactly the same for physical device:
> 1. $./testpmd -w :08:00:1 -- -i
> 2. testpmd> port detach
>
> But you don't call rte_eal_devargs_add with RTE_DEVTYPE_WHILISTED_PCI
> in  rte_eal_dev_attach_pdev ?

Yes, I don't.
Hotplug functions should not change BLACKLIST and WHITELIST.
So not to touch the list is correct behavior.

I guess you feel something strange about usage of devargs_list.
If so, I agree with it.
Probably the issue is that devargs_list is used for not only storing
command parameters, but also not to register same virtual device name twice.

> Thus it makes the hotplug implementation not coherent for me.
>
> What do you think ?

Anyway, here is my guess.

Current DPDK uses devargs not to register same virtual device name.
If we follow this, probably using devargs is straight forward.

But if we should change the design itself, could you check below.
http://dpdk.org/dev/patchwork/patch/3374/
Thomas and I agreed that I will try to change design in post-rc1.

In a future patch, probably it might be nice to have virtualdev_list,
then we can use devargs_list only for storing command arguments.

Regards,
Tetsuya

> Regards,
>
> Maxime




[dpdk-dev] [PATCH v2 0/4] Mellanox ConnectX-3 PMD

2015-02-21 Thread Adrien Mazarguil
This PMD adds support for Mellanox ConnectX-3-based adapters through the
verbs framework. It relies on external libraries (libibverbs and user space
driver libmlx4) and kernel support to do so.

While these libraries and kernel modules are available on OpenFabrics
Alliance's website [1] and provided by package managers on most
distributions, this PMD requires Ethernet extensions that may not be
supported at the moment (this is a work in progress).

Mellanox OFED [2] includes the necessary support and should be used in the
meantime. For DPDK, only libibverbs, libmlx4 and mlnx-ofed-kernel packages
are required from that distribution.

The following kernel modules must be loaded before using this PMD:

- mlx4_core (hardware driver, does global initialization)
- mlx4_en (Ethernet device driver)
- mlx4_ib (InfiniBand device driver)
- ib_uverbs (user space driver for verbs)

[1] https://www.openfabrics.org/
[2] 
http://www.mellanox.com/page/products_dyn?product_family=26&mtag=linux_sw_drivers

v2:
 - Include minor bugfix for VLAN filtering.
 - Add maintainers entry.
 - Add documentation.

Adrien Mazarguil (4):
  scripts: add auto-config-h.sh
  mlx4: new poll mode driver
  maintainers: claim responsibility for mlx4 PMD
  doc: add librte_pmd_mlx4 documentation

 MAINTAINERS  |4 +
 config/common_bsdapp |   11 +
 config/common_linuxapp   |   11 +
 doc/guides/prog_guide/index.rst  |1 +
 doc/guides/prog_guide/mlx4_poll_mode_drv.rst |  327 ++
 doc/guides/prog_guide/source_org.rst |1 +
 lib/Makefile |1 +
 lib/librte_pmd_mlx4/Makefile |  119 +
 lib/librte_pmd_mlx4/mlx4.c   | 4739 ++
 lib/librte_pmd_mlx4/mlx4.h   |  166 +
 mk/rte.app.mk|8 +
 scripts/auto-config-h.sh |  137 +
 12 files changed, 5525 insertions(+)
 create mode 100644 doc/guides/prog_guide/mlx4_poll_mode_drv.rst
 create mode 100755 lib/librte_pmd_mlx4/Makefile
 create mode 100755 lib/librte_pmd_mlx4/mlx4.c
 create mode 100644 lib/librte_pmd_mlx4/mlx4.h
 create mode 100755 scripts/auto-config-h.sh

-- 
1.9.1



[dpdk-dev] [PATCH v2] mk: Only default to -Werror when building from git checkout

2015-02-21 Thread Thomas Monjalon
2015-02-20 18:15, Stephen Hemminger:
> On Fri, 20 Feb 2015 13:15:38 +0100
> Thomas Monjalon  wrote:
> 
> > 2015-02-12 17:18, Panu Matilainen:
> > > Add RTE_DEVEL_BUILD make-variable which can be used to do things
> > > differently when doing development vs building a release,
> > > autodetected from source root .git presence and overridable via
> > > commandline. Use it to only enable -Werror compiler flag when
> > > building a git checkout:
> > > 
> > > Failing build on warnings is a useful developer tool but its bad
> > > for release tarballs which can and do get built with newer
> > > compilers than what was used/available during development. Compilers
> > > routinely add new warnings so code which built silently with cc X
> > > might no longer do so with X+1. This doesn't make the existing code
> > > any more buggier and failing the build in this case does not help
> > > not help improve code quality of an already released version either.
> > 
> > Please, could you update documentation to explain RTE_DEVEL_BUILD option?
> > Some users could try to build from git, so we should advise to disable 
> > RTE_DEVEL_BUILD.
> > These files might be updated:
> > http://dpdk.org/browse/dpdk/tree/doc/build-sdk-quick.txt
> > http://dpdk.org/browse/dpdk/tree/doc/guides/linux_gsg/build_dpdk.rst
> > http://dpdk.org/browse/dpdk/tree/doc/guides/freebsd_gsg/build_dpdk.rst
> > 
> > http://dpdk.org/browse/dpdk/tree/doc/guides/prog_guide/dev_kit_build_system.rst
> > 
> > Thanks
> 
> Also do not allow any patches to into upstream that cause
> new warnings with latest stable version of Gcc or Clang?
> I don't want a clean project to get littered with warning graffiti.
> Maybe a build bot?

Yes there are some daily builds with many compilers/distros.
We'll have to be sure that they are done in devel mode (with -Werror).
Anyway devel build is a sanity check which should be done by every developers
and reviewers.



[dpdk-dev] [PATCH v10 13/14] eal/pci: Add rte_eal_dev_attach/detach() functions

2015-02-21 Thread Maxime Leroy
Hi Tetsuya,

On Sat, Feb 21, 2015 at 4:49 AM, Tetsuya Mukawa  wrote:
> On 2015/02/21 0:20, Maxime Leroy wrote:
[...]
>> Why you want to add devargs in the devargs_list, if there are no needs
>> to store this information ?
>
> In eal initialization code, virtual device names stored in devargs are
> checked not to register a same device name twice.
> And each init function of PMD just trust a device name received by eal.
> So there is no code in PMD to check whether device name is unique.
>

I disagree with you. This check is not present in the master branch.

You have added this check in your hotplug patchset, in this patch:
[PATCH v10 10/14] eal/pci: Add a function to remove the entry of
devargs list
See: http://dpdk.org/ml/archives/dev/2015-February/013712.html

Thus the problem should be already exist without your patches in the
master branch.

For example according to you, this testpmd command should create 2
devices with the same name:
testpmd -c 0xc --vdev eth_pcap0,iface=eth0 --vdev eth_pcap0,iface=eth1
-n 2 -- -i

But it's not the case:
PMD: Initializing pmd_pcap for eth_pcap0
PMD: Creating pcap-backed ethdev on numa socket 0
PMD: Initializing pmd_pcap for eth_pcap0
PMD: Creating pcap-backed ethdev on numa socket 0
PMD: rte_eth_dev_allocate: Ethernet Device with name eth_pcap0 already
allocated!

In fact, it's not possible for any PMD_VDEV in the dpdk repo to create
2 devices with the same name.
All the virtual device initialization functions use the
rte_eth_dev_allocate function. This function prevents to create two
ethernet devices with the same name:

 if (rte_eth_dev_allocated(name) != NULL) {
PMD_DEBUG_TRACE("Ethernet Device with name %s already
allocated!\n", name);
return NULL;
}


> For example, according to your suggestion, how to prevent below case?
> $ ./testpmd -c f -n 1 -- -i
> testpmd> port attach eth_pcap0,iface=eth0
> testpmd> port attach eth_pcap0,iface=eth1
>
> Also, type below, after doing above.
> testpmd> port detach 0
>
> Probably port 0 will be "eth_pcap0,iface=eth0".
> But uninit code of PMD only receives a device name like 'eth_pcap0'.
> (We have 2 'eth_pcap0' devices in PMD.)
>
> To prevent above case, probably we have 2 options at least.
> One is changing init code of all virtual PMDs not to register same
> device name.

There are no need to change init code of all virtual PMDs to not
register the same device name 2 times.
Because it's already not possible to create 2 virtual device with the
same name. (see my point above)

> The other is to use devargs_list in EAL, and call init code of PMD with
> a unique device name.

Thus there are no needs to use the devargs_list for that.

>
[..]
>>
>> But you don't call rte_eal_devargs_add with RTE_DEVTYPE_WHILISTED_PCI
>> in  rte_eal_dev_attach_pdev ?
>
> Yes, I don't.
> Hotplug functions should not change BLACKLIST and WHITELIST.
> So not to touch the list is correct behavior.

Yes the correct behaviour for Hotplug functions is to not use the
devargs_list for physical and virtual devices !

Regards,

Maxime


[dpdk-dev] [PATCH] Make -Werror optional

2015-02-21 Thread Neil Horman
On Fri, Feb 20, 2015 at 05:55:21PM -0800, Stephen Hemminger wrote:
> On Thu, 12 Feb 2015 16:54:44 +0200
> Panu Matilainen  wrote:
> 
> > On 02/12/2015 04:38 PM, Stephen Hemminger wrote:
> > > On Thu, 12 Feb 2015 13:13:22 +0200
> > > Panu Matilainen  wrote:
> > >
> > >> This adds new CONFIG_RTE_ERROR_ON_WARNING config option to enable
> > >> fail-on-warning compile behavior, defaulting to off.
> > >>
> > >> Failing build on warnings is a useful developer tool but its bad
> > >> for release tarballs which can and do get built with newer
> > >> compilers than what was used/available during development. Compilers
> > >> routinely add new warnings so code which built silently with cc X
> > >> might no longer do so with X+1. This doesn't make the existing code
> > >> any more buggier and failing the build in this case does not help
> > >> not help improve code quality of an already released version either.
> 
> Hopefully distro's like RHEL will build with -Werror enabled
> and not allow build to go through with errors.
> 
Thats usually what we do, yes.
Neil

> 
> 


[dpdk-dev] Appropriate DPDK data structures for TCP sockets

2015-02-21 Thread Matthew Hall
Hello fellow stack hackers :) ,

I'm working on a simple server-side implementation of TCP on DPDK.

For this to work I need a good data structure to store some sockets.

The lookup key is like this:

struct ss_flow_key_s {
uint8_t  sip[IPV6_ALEN];
uint8_t  dip[IPV6_ALEN];
uint16_t sport;
uint16_t dport;
uint8_t  protocol;
} __attribute__((packed));

typedef struct ss_flow_key_s ss_flow_key_t;

The socket itself is like this:

enum ss_tcp_state_e {
SS_TCP_CLOSED   = 0, SS_TCP_LISTEN   = 1, SS_TCP_SYN_TX   = 2,
SS_TCP_SYN_RX   = 3, SS_TCP_OPEN = 4, SS_TCP_UNKNOWN  = -1,
};

typedef enum ss_tcp_state_e ss_tcp_state_t;

// RFC 793, RFC 1122
struct ss_tcp_socket_s {
ss_flow_key_t  key;
uint32_t id;
rte_spinlock_t lock;

ss_tcp_state_t state;

uint32_t ticks_last;
uint16_t rx_buf_offset;
uint16_t mss;
uint64_t rx_failures;
uint8_t  rx_data[L4_TCP_WINDOW_SIZE * 2];
} __rte_cache_aligned;

So far I was using rte_hash, but it's single writer multi reader, which is 
eventually going to need some more complicated locking and probably run kind of 
slow. Also, I need some timer functions to delete dead sockets and so forth, 
and rte_hash doesn't have any iteration API.

So then I was trying to figure out if I needed to use a linked list for the 
iteration or if there is some other API I should use instead like rte_table_*. 
However the documentation of rte_table is kind of confusing so I wasn't sure if 
that was the right choice either.

Any advice?

Thanks,
Matthew.


[dpdk-dev] [PATCH 00/15] migrate flow director in ixgbe driver to new API

2015-02-21 Thread Thomas Monjalon
> > The patch set uses new filter_ctrl API to replace old flow director filter 
> > APIs.
> > It uses new functions and structure to replace old ones in ixgbe driver, 
> > updates
> > commands to replace old ones in testpmd, and removes the old APIs
> > 
> > Jingjing Wu (15):
> >   ixgbe: migrate flow director filter operations (add/delete/update) to
> > new API
> >   ethdev: extend flow type and flexible payload type definition for flow
> > director
> >   ixgbe: implement the flexpayload configuration of flow director filter
> >   app/test: remove the flexbytes_offset setting in test_link_bonding
> >   testpmd: remove the flexbytes_offset setting
> >   ethdev: remove flexbytes_offset from rte_fdir_conf
> >   ethdev: structures definition for flow director masks
> >   ixgbe: implement the mask configuration of flow director filter
> >   ixgbe: implement the get info and statistic operations of flow
> > director
> >   ixgbe: implement the flush operation of flow director
> >   testpmd: add and update commands for flow director
> >   testpmd: update function to show flow director information
> >   testpmd: set the default value of flow director's mask
> >   testpmd: remove old commands for flow director
> >   doc: commands changed in testpmd_funcs.rst for flow director
> 
> Acked-by: Helin Zhang 

Applied, thanks.
Some patches were merged (example: doc update with matching code update).

Now we wait for enic to be converted to the new flow director API,
in order to remove the old API.